#!/bin/bash
#
# Copyright (C) Mellanox Technologies Ltd. 2016.  ALL RIGHTS RESERVED.
# See file LICENSE for terms.
#

PARAMS_GLOBAL=$(dirname $0)/../conf/sharp_params.ini
PARAMS_LOCAL=~/.sharp_local.ini

set_local_params()
{
	cat > $PARAMS_LOCAL << EOF
#
# Copyright (C) Mellanox Technologies Ltd. 2016.  ALL RIGHTS RESERVED.
# Generated by $(basename $0).
#
EOF

	for x in $(grep -v '^#' $PARAMS_GLOBAL); do
		var=$(echo "$x" | cut -f1 -d'=')
		val="${!var}"
		[ -n "$val" ] && echo "$var=\"$val\"" >> $PARAMS_LOCAL
	done
}

read_ini_params()
{
	_file=$1
	_pref=$2

	[ -n "$_file" ] && [ ! -f "$_file" ] && return 0

	for x in $(grep -v '^#' $_file); do
		var=$(echo "$x" | cut -f1 -d'=')
		val=$(echo "$x" | cut -f2 -d'=')
		[ -n "$val" ] && eval ${_pref}_${var}=$val
	done

	return  0
}

get_slurm_nodes()
{
	_pref=$1

	var=${_pref}_hostlist

	[ -n "${!var}" ] && return 0

	if [ -z "$SLURM_NODELIST" ] && [ $(squeue 2>/dev/null | grep $(whoami) | wc -l) -eq 1 ]; then
		SLURM_NODELIST=$(squeue 2>/dev/null | grep $(whoami) | awk '{print $NF}')
	fi

	[ -n "$SLURM_NODELIST" ] && eval $var=$(hostlist -e $SLURM_NODELIST -s,) || eval $var=""
}

reset_vars()
{
	_file=$1
	_pref=$2

	for x in $(grep -v '^#' $_file); do
		gvar=$(echo "$x" | cut -f1 -d'=')
		lvar=${_pref}_${gvar}

		[ -z "${!gvar}" ] && eval $gvar=${!lvar}
	done

	return  0
}

load_params()
{
	if [ $# -eq 0 ]; then
		prefix=$(basename $0 .sh)
	else
		prefix=$1
	fi

	get_slurm_nodes $prefix

	local_prefix="xyz"
	read_ini_params $PARAMS_GLOBAL $local_prefix
	read_ini_params $PARAMS_LOCAL $local_prefix
	reset_vars $PARAMS_GLOBAL $local_prefix
}
